import 'package:consoledoctor_common/consoledoctor_common.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

Future<void> showAlertMessage(BuildContext context, String title, String body, { String buttonText = "OK"}) {
  return showAlert(context, title, [Text(body)], buttonText: buttonText);
}

Future<void> showAlert(BuildContext context, String title, List<Widget> body, { String buttonText = "OK"}) async {
  return showDialog<void>(
    context: context,
    barrierDismissible: false, // user must tap button!
    builder: (BuildContext context) {
      return AlertDialog(
        title: Text(title),
        content: SingleChildScrollView(
          child: ListBody(
            children: body,
          ),
        ),
        actions: <Widget>[
          TextButton(
            child: Text(buttonText),
            onPressed: () {
              Navigator.of(context).pop();
            },
          ),
        ],
      );
    },
  );
}


Future<void> showNativeAlertMessage(BuildContext context, String title, String body, { String buttonText = "OK"}) {
  return showNativeAlert(context, title, [Text(body)], buttonText: buttonText);
}

Future<void> showNativeAlert(BuildContext context, String title, List<Widget> body, { String buttonText = "OK"}) async {
  if (Theme.of(context).platform == TargetPlatform.iOS) {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return CupertinoAlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: ListBody(
              children: body,
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(buttonText),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  } else {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: ListBody(
              children: body,
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(buttonText),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
          ],
        );
      },
    );
  }
}

Future<bool?> showNativeYesNoAlert(BuildContext context, String title, String message, {String yesButtonText = "YES", String noButtonText = "NO", bool allowModalClose = false}) {
  if (Theme.of(context).platform == TargetPlatform.iOS) {
    // Use CupertinoAlertDialog for iOS
    return showCupertinoDialog<bool>(
      context: context,
      barrierDismissible: allowModalClose,
      builder: (context) {
        return CupertinoAlertDialog(
          title: Text(title),
          content: Text(message),
          actions: <Widget>[
            CupertinoDialogAction(
              onPressed: () {
                Navigator.of(context).pop(false);
              },
              child: Text(noButtonText),
            ),
            CupertinoDialogAction(
              onPressed: () {
                Navigator.of(context).pop(true);
              },
              child: Text(yesButtonText),
            ),
          ],
        );
      },
    );
  } else {
    // Use Material AlertDialog for Android
    return showDialog<bool>(
      context: context,
      builder: (context) {
        return AlertDialog(
          title: Text(title),
          content: Text(message),
          actions: <Widget>[
            TextButton(
              onPressed: () {
                Navigator.of(context).pop(false);
              },
              child: Text(noButtonText),
            ),
            TextButton(
              onPressed: () {
                Navigator.of(context).pop(true);
              },
              child: Text(yesButtonText),
            ),
          ],
        );
      },
    );
  }
}

Future<T?> showNativeChoiceDialog<T>(BuildContext context, String title, Map<String, T> options, {String cancelButtonText = "Cancel", T? cancelButtonVal}) {
  return context.theme.platform == TargetPlatform.iOS
    ? showCupertinoModalPopup<T?>(
      context: context,
      builder: (BuildContext context) {
        return CupertinoActionSheet(
          title: Text(title),
          actions: options.entries.map((option) =>
              CupertinoActionSheetAction(
                onPressed: () => Navigator.pop(context, option.value),
                child: Text(option.key),
              )
          ).toList(),
          cancelButton: CupertinoActionSheetAction(
            onPressed: () => Navigator.pop(context, cancelButtonVal),
            child: Text(cancelButtonText),
          ),
        );
      },
    )
    : showDialog<T?>(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: options.entries.map((option) =>
                  ListTile(
                    title: Text(option.key),
                    onTap: () => Navigator.pop(context, option.value),
                  )
              ).toList(),
            ),
          ),
          actions: <Widget>[
            TextButton(
              onPressed: () => Navigator.pop(context, cancelButtonVal),
              child: Text(cancelButtonText),
            ),
          ],
        );
      },
    );
}